@@ -1,9 +1,16 @@
 #!/bin/sh
-# $Id: run_test.sh,v 1.11 2005/08/14 17:50:38 tom Exp $
+# $Id: run_test.sh,v 1.13 2007/09/05 00:27:57 tom Exp $
 # Test-script for DIFFSTAT
+
+# change this for ad hoc testing of compression
+#TYPE=.pat.Z
+#TYPE=.pat.gz
+#TYPE=.pat.bz2
+TYPE=.pat
+
 if [ $# = 0 ]
 then
-	eval '"$0" *.pat'
+	eval '"$0" *${TYPE}'
 	exit
 fi
 PATH=`cd ..;pwd`:$PATH; export PATH
@@ -12,11 +19,11 @@ PATH=`cd ..;pwd`:$PATH; export PATH
 
 for item in $*
 do
-	echo "testing `basename $item .pat`"
-	for OPTS in "" "-p1" "-p9" "-f0" "-u" "-k" "-r1" "-r2"
+	echo "testing `basename $item $TYPE`"
+	for OPTS in "" "-p1" "-p9" "-f0" "-u" "-k" "-r1" "-r2" "-b"
 	do
-		NAME=`echo $item | sed -e 's/.pat$//'`
-		DATA=$NAME.pat
+		NAME=`echo $item | sed -e 's/'$TYPE'$//'`
+		DATA=${NAME}${TYPE}
 		if [ ".$OPTS" != "." ] ; then
 			NAME=$NAME`echo ./$OPTS|sed -e 's@./-@@'`
 		fi
